@@ -251,8 +251,10 @@ class HTTPClient:
             if reason:
                 headers["X-Audit-Log-Reason"] = _uriquote(reason, safe="/ ")
 
-        kwargs["headers"] = headers
+        if locale := kwargs.pop('locale', None):
+            headers["X-Discord-Locale"] = locale
 
+        kwargs["headers"] = headers
         # Proxy support
         if self.proxy is not None:
             kwargs["proxy"] = self.proxy
@@ -1314,8 +1316,23 @@ class HTTPClient:
             payload["icon"] = icon
         return self.request(Route("POST", "/guilds/templates/{code}", code=code), json=payload)
 
-    def get_bans(self, guild_id: Snowflake) -> Response[List[guild.Ban]]:
-        return self.request(Route("GET", "/guilds/{guild_id}/bans", guild_id=guild_id))
+    def get_bans(
+            self,
+            guild_id: Snowflake,
+            limit: Optional[int] = None,
+            before: Optional[Snowflake] = None,
+            after: Optional[Snowflake] = None,
+    ) -> Response[List[guild.Ban]]:
+        params: Dict[str, Union[int, Snowflake]] = {}
+
+        if limit is not None:
+            params["limit"] = limit
+        if before is not None:
+            params["before"] = before
+        if after is not None:
+            params["after"] = after
+
+        return self.request(Route("GET", "/guilds/{guild_id}/bans", guild_id=guild_id), params=params)
 
     def get_ban(self, user_id: Snowflake, guild_id: Snowflake) -> Response[guild.Ban]:
         return self.request(
@@ -1865,9 +1882,13 @@ class HTTPClient:
             "channel_id",
             "topic",
             "privacy_level",
+            "send_start_notification",
         )
         payload = {k: v for k, v in payload.items() if k in valid_keys}
 
+        if payload.get("send_start_notification") is not None:
+            payload["send_start_notification"] = int(payload["send_start_notification"])
+
         return self.request(Route("POST", "/stage-instances"), json=payload, reason=reason)
 
     def edit_stage_instance(
@@ -2017,17 +2038,25 @@ class HTTPClient:
 
     # Application commands (global)
 
-    def get_global_commands(self, application_id: Snowflake) -> Response[List[interactions.ApplicationCommand]]:
+    def get_global_commands(
+        self, application_id: Snowflake, *, with_localizations: bool = True, locale: str = None,
+    ) -> Response[List[interactions.ApplicationCommand]]:
+        params = {
+            "with_localizations": int(with_localizations)
+        }
+
         return self.request(
             Route(
                 "GET",
                 "/applications/{application_id}/commands",
                 application_id=application_id,
-            )
+            ),
+            params=params,
+            locale=locale,
         )
 
     def get_global_command(
-        self, application_id: Snowflake, command_id: Snowflake
+        self, application_id: Snowflake, command_id: Snowflake, locale: str = None,
     ) -> Response[interactions.ApplicationCommand]:
         r = Route(
             "GET",
@@ -2035,7 +2064,7 @@ class HTTPClient:
             application_id=application_id,
             command_id=command_id,
         )
-        return self.request(r)
+        return self.request(r, locale=locale)
 
     def upsert_global_command(self, application_id: Snowflake, payload) -> Response[interactions.ApplicationCommand]:
         r = Route(
